const {Commander} = require("./commander.js");
const {Builder} = require("selenium-webdriver");

exports.Runner = class Runner {
	constructor(driverUrl, capabilities) {
		this.driverUrl = driverUrl;
		this.capabilities = capabilities;
	}
	async executeScript(code, validate) {
		let r = await this.cmd.executeScript(code);
		if(validate)
			validate(r);
	}
	async run(url, scenario) {
		const startTime = new Date();
		const driver = new Builder()
			.usingServer(this.driverUrl)
			.withCapabilities(this.capabilities)
			.build();
		const cmd = new Commander(driver);
		let action = null;
		try {
			await cmd.get(url);
			for(action of scenario) {
				if(action.action === "log")
					console.log(action.data);
				else if(action.action === "delay")
					await cmd.delay(action.timeout);
				else if(action.action === "resetMousePosition")
					await cmd.resetMousePosition();
				else if(action.action === "waitURL")
					await cmd.waitURL(action.url,action.timeout);
				else if(action.action === "waitVisible")
					await cmd.waitVisible(action.target,action.timeout);
				else if(action.action === "waitAlert")
					await cmd.waitAlert(action.timeout);
				else if(action.action === "dismissAlert")
					await cmd.dismissAlert();
				else if(action.action === "exec")
					await cmd.executeScript(action.script, action.validate);
				else if(action.action === "screenShot")
					await cmd.takeScreenshot(action);
				else if(action.action === "click")
					await cmd.mouseClick(action.target, action.offset, action.timeout);
				else if(action.action === "move")
					await cmd.mouseMove(action.target, action.offset, action.timeout);
				else if(action.action === "sendKeys")
					await cmd.sendKeys(action.target, action.key);
				else
					throw new Error("unknown action '"+action.action+"'");
			}
		}
		catch(e) {
			console.error("ERROR:"+(action?JSON.stringify(action):"")+"\n"+e.name+":"+e.message);
			try {
				await cmd.takeScreenshot({save:"images/error.png"});
			}
			catch(e) {
				console.error(e);
			}
			throw new Error("テスト失敗");
		}
		finally {
			if(driver)
				await driver.quit();
		}
	}
};
