import "@babel/polyfill";
import { Builder, Capabilities, Key } from "selenium-webdriver";
import {AppURL, DriverURL} from "../setting.js";
const {Runner} = require("../runner.js");

let runner = null;
describe("User Registration", () => {
	beforeEach(async () => {
		const capabilities = new Capabilities()
			.set("scriptFilter",["\\.html"])
			.setBrowserName("safari+G.O");
		runner = new Runner(DriverURL, capabilities);
	});

	afterEach(async () => {
	});

	it("Normal case of user registration", async () => {
		await runner.run(AppURL, [
			// 「トップメニュー」のクリックによるalert表示
			{action:"click", target:"</html/body/div[1]/header/div/h1",timeout:3000},
			{action:"waitAlert", timeout:1000},
			{action:"dismissAlert"},
			{action:"exec", script:'return appData;', validate:(appData)=>{if(appData!=="hello") throw new Error("appData is not true. appData=" + appData);}},
			// アコーディオンメニューの選択
			{action:"click", target:"</html/body/ul/li[4]/div"},
			{action:"waitVisible", target:"#userreg", timeout:3000},
			// スクリーンキャプチャによるメニュー表示テスト
			{action:"delay", timeout:700},
			{action:"screenShot", compare:"a4cc7834d3f1df879ee9361eb73943735a05792b6a1ed72671692e83ad074bd8", saveOnError:"images/snapshot.png"},
			// ユーザ登録ページへ
			{action:"click", target:"#userreg"},
			{action:"waitURL", url:/^http.*\/demo\/reg\.html$/, timeout:1000},
			{action:"resetMousePosition"},
			// ユーザ情報の入力
			{action:"click", target:"#name1"},
			{action:"delay", timeout:100},
			{action:"sendKeys", key:["[HanjaMode On]yamada",Key.SPACE,Key.RETURN," tarou",Key.SPACE,Key.RETURN,"[HanjaMode Off]"]},
			{action:"sendKeys", key:Key.TAB},
			{action:"sendKeys", key:"Tarou.Yamada@nexaweb.com[Select All][Copy]"},
			{action:"sendKeys", key:Key.TAB},
			{action:"sendKeys", key:"[Paste]"},
			{action:"sendKeys", key:Key.TAB},
			{action:"sendKeys", key:"080-4321-8765"},
			{action:"click", target:"</html/body/div[2]/form/div/div[5]/div/label[1]/input"},
			{action:"click", target:"#job"},
			{action:"delay", timeout:500},
			{action:"click", target:"#job", offset:{x:250,y:-250}},
			{action:"click", target:"</html/body/div[2]/form/div/div[7]/div[1]/label/input"},
			{action:"click", target:"</html/body/div[2]/form/div/div[7]/div[3]/label/input"},
			// 送信
			{action:"click", target:"</html/body/div[2]/form/div/button"},
			{action:"waitURL", url:/^http.*\/demo\/result\.html\?.*$/, timeout:1000},
		]);
	});

	it("Case where no phone number is entered", async () => {
		await runner.run(AppURL, [
			// アコーディオンメニューの選択
			{action:"click", target:"</html/body/ul/li[4]/div",timeout:3000},
			{action:"waitVisible", target:"#userreg", timeout:3000},
			// スクリーンキャプチャによるメニュー表示テスト
			{action:"delay", timeout:700},
			{action:"screenShot", compare:"a4cc7834d3f1df879ee9361eb73943735a05792b6a1ed72671692e83ad074bd8", saveOnError:"images/snapshot.png"},
			// ユーザ登録ページへ
			{action:"click", target:"#userreg"},
			{action:"waitURL", url:/^http.*\/demo\/reg\.html$/, timeout:1000},
			{action:"resetMousePosition"},
			// ユーザ情報の入力
			{action:"click", target:"#name1"},
			{action:"delay", timeout:100},
			{action:"sendKeys", key:["[HanjaMode On]yamada",Key.SPACE,Key.RETURN," tarou",Key.SPACE,Key.RETURN,"[HanjaMode Off]"]},
			{action:"sendKeys", key:Key.TAB},
			{action:"sendKeys", key:"Tarou.Yamada@nexaweb.com[Select All][Copy]"},
			{action:"sendKeys", key:Key.TAB},
			{action:"sendKeys", key:"[Paste]"},
			{action:"sendKeys", key:Key.TAB},
			{action:"click", target:"</html/body/div[2]/form/div/div[5]/div/label[1]/input"},
			{action:"click", target:"#job"},
			{action:"delay", timeout:500},
			{action:"click", target:"#job", offset:{x:250,y:-250}},
			{action:"click", target:"</html/body/div[2]/form/div/div[7]/div[1]/label/input"},
			{action:"click", target:"</html/body/div[2]/form/div/div[7]/div[3]/label/input"},
			// 送信
			{action:"click", target:"</html/body/div[2]/form/div/button"},
			{action:"delay", timeout:1000},
			{action:"waitURL", url:/^http.*\/demo\/reg\.html$/, timeout:0},
		]);
	});
});
